#
# spec file for package meep
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 32
Name:           meep
Version:        1.28.0
Release:        1.3
Summary:        FDTD finite-difference time-domain solver
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://meep.readthedocs.io/en/latest/
Source0:        https://github.com/NanoComp/meep/releases/download/v%{version}/meep-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  binutils
BuildRequires:  blas-devel
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gmp-devel
BuildRequires:  gsl-devel
BuildRequires:  guile-devel
BuildRequires:  harminv-devel
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  libctl-devel >= 4.2.0
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel

# providing ice-9/boot-9.scm
Requires:       guile

# providing /usr/share/libctl/base/include.scm
Requires:       libctl-devel >= 4.2.0

%description
Meep (or MEEP) is a free finite-difference time-domain (FDTD)
simulation software package developed at MIT to model electromagnetic
systems.

%package -n     lib%{name}%{somajor}
Summary:        FDTD finite-difference time-domain solver library
# Avoid unresolvable errors from multiple providers
Group:          System/Libraries

%description -n lib%{name}%{somajor}
Meep (or MEEP) is a free finite-difference time-domain (FDTD)
simulation software package developed at MIT to model electromagnetic
systems.

%package        devel
Summary:        Libraries and header files for meep library
Group:          Development/Libraries/Other
Requires:       lib%{name}%{somajor} = %{version}

%description    devel
Meep (or MEEP) is a free finite-difference time-domain (FDTD)
simulation software package developed at MIT to model electromagnetic
systems.

This package contains libraries and header files for developing
applications that use meep.

%prep
%setup -q
# Checking for CPU architecture is totally broken, get rid of it
sed -i -e 's/AX_CXX_MAXOPT//' configure.ac

%build
# Missing version.sh from tarball, required for autoreconf
echo "echo -n '%{version}'" > ./version.sh ; chmod +x ./version.sh
autoreconf
# On i586, we need SSE (implicit on x86_64). Yes, we need a Pentium3 at least ...
%ifarch %{ix86}
%global optflags %{optflags} -msse -Wno-error=return-type
%else
%global optflags %{optflags} -Wno-error=return-type
%endif
# Specify fortran libraries manually, autoconf (fortran.m4) mechanism is
# totally broken and messes up pkgconfig file later
%configure \
  FLIBS="-lgfortran" \
  --enable-shared \
  --disable-static \
  --with-openmp \
  --enable-portable-binary
%make_build
# Build tests without running any
%make_build check TESTS=

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
grep -E "flags|model name"  /proc/cpuinfo | head -n2
# https://github.com/NanoComp/meep/issues/727
make check TESTS=2D_convergence || export xfail=2D_convergence
%make_build check XFAIL_TESTS=${xfail}
cat tests/test-suite.log

%post -n lib%{name}%{somajor} -p /sbin/ldconfig

%postun -n lib%{name}%{somajor} -p /sbin/ldconfig

%files
%doc AUTHORS NEWS.md
%license COPYRIGHT
%{_bindir}/meep
%{_datadir}/meep/

%files -n lib%{name}%{somajor}
%{_libdir}/libmeep.so.*

%files devel
%{_libdir}/libmeep.so
%{_libdir}/pkgconfig/*
%{_includedir}/*

%changelog
* Tue Apr 16 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.28.0:
  * Improved special field updates for r=0 in cylindrical
    coordinates
  * Geometric objects now have a label field that appears when
    Simulation.plot2D is called with label_geometry=True
  * Various improvements and minor bug fixes and additional
    documentation.
- Changes from version 1.27.0:
  * Support for spectral extrapolation using Padé
    approximants (#2440).
  * Support for periodic design regions of adjoint solver
    (#2465, #2518).
  * Support for "unfiltering" a given set of design weights for
    adjoint optimization (#2462).
  * MPB is no longer a required dependency
  * Bug fix for sources at in cylindrical coordinates
  * Additional unit tests and documentation and various
    improvements and minor bug fixes
* Fri Mar 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.26.0:
  * Improved Gaussian beam source in 2D ([#2333]).
  * Support for returning the number of timesteps elapsed in
    simulation ([#2337]).
  * Bug fix for fields update in cylindrical coordinates
  * Bug fix for PMLs in cylindrical coordinates ([#2383]).
  * Bug fix in amplitude function of eigenmode source ([#2394]).
  * The `doc/` directory (the manual) is no longer included in
    the release tarball to save space, since most people will
    view this online.  (It is still in the git repository.)
  * Various improvements and minor bug fixes ([#2321], [#2349],
    [#2371], [#2380], [#2390], [#2413]), and additional unit
    tests and documentation ([#2314], [#2360], [#2364], [#2365],
    [#2387], [#2395], [#2402]).
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.25.0:
  * Support for connectivity constraints in adjoint solver (#2207).
  * Support for animation in topology optimization (#2186).
  * Support for load_minus_flux in adjoint solver (#2271).
  * Support colorbars in plot2D (#2289).
  * Support for plot3D (#2305).
  * Various improvements and bug fixes
  * Support for adjoint gradients of local density of states (LDOS) (#2077).
  * Improvements to memory usage of adjoint solver (#1855).
  * Various bugfixes (#1959, #2044, #2066, #2073, #2079, #2091, #2095, #2114) and additional unit tests (#2032, #2049, #2053, #2076, #2082).
  * Support for termination condition function based on the field energy in the entire cell (#2021).
  * Support for mode decomposition for 2d cell with out of plane wavevector (#1968).
  * Type annotations for the Simulation class (#1919).
  * Various improvements (#1821, #1895, #2027), bug fixes (#1955, #2016), and additional documentation (#2005).
* Mon Jul 11 2022 Atri Bhattacharya <badshah400@gmail.com>
- Disable '2D_convergence' test on all archs to avoid build
  failures.
* Wed Feb  9 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.22.0:
  * Too many changes, see included NEWS.md or
    https://github.com/NanoComp/meep/blob/v1.22.0/NEWS.md
- Build with openMP.
- Fix meep.pc pkgconfig file.
- Drop disable_test_tumbleweed.patch, use XFAIL_TESTS instead.
  Reenable on all archs but x86_64, disable also on 15.x
- Remove latex2html BuildRequires, doc uses Markdown now.
* Mon May 27 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.9.0:
  * Adjoint solver to compute sensitivity of solution to material
    perturbations (#795).
  * Experimental do_averaging feature for user-defined material
    functions (#771, #791).
  * Periodic boundaries support in near2far via nperiods option
    (#769, #789).
  * Capture more output in Python notebooks (#785, #807).
  * dft-energy feature (#744, #747).
  * Eigenmode sources are normalized to unit power (#728).
  * Fix interpolation of DFT slice output (#787).
  * Bug fix in run-k-points (#779).
  * Eigenmode sources for negative angles (#752).
  * Various other minor bugfixes, build fixes, documentation
    improvements, tutorials, etcetera.
- increase somajor to 14
- add patch disable_test_tumbleweed.patch to disable failing test
  on Tumbleweed (boo#1130438)
* Tue Feb 19 2019 jbrielmaier@suse.de
- Update to version 1.8.0:
  * Add `--without-scheme` flag to `./configure` (#705)
  * Improve error messages in Python interface (#699)
  * Allow `kguess` to specify MPB lattice vector for launching
    oblique waveguide modes (#675)
  * Allow user materials when checking for conductivity (#689)
  * Add `split_chunks_evenly` flag to `Simulation` constructor.
    Setting to `False` will improve parallel simulation performance
    by dividing chunks based on work instead of size (#681)
  * Added `Simulation.visualize_chunks()` to visualize the chunk
    layout (#671)
  * Improved stability of lorentzian susceptibility (#666)
  * Get array metadata for `get_array` and `get_dft_array` (#655)
  * Add ability to get a source slice as a numpy array (#652)
  * Fixed performance issues in ModeSolver.find_k (#644)
  * Add `force_all_components` flag to `Simulation` constructor
  * Expose `run_k_point` to access more Harminv data (#626)
  * Various other bug fixes, documentation improvements, etc.
- drop patch:
  namespace-for-complex-literals.patch: included in release
- require libctl >= 4.2
- remove libmeepgeom package as it was merged into libmeep
- increase somajor to 13
- don't build with C++14 support anymore, as meep now works fine
  with C++11 again
* Thu Nov 22 2018 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.7.0:
  * See /usr/share/meep/NEWS.md
- update so version to 12
- add patch:
  * namespace-for-complex-literals.patch: fixes build failure
- drop patch:
  * meep_change_protos_with_harminv_complex.patch
- add libmeepgeom library
- correct doc file names
- use c++14 for complex_literals
* Fri Jan 20 2017 wagner-thomas@gmx.at
- added two requirements to make meep start
* Mon Aug 31 2015 toddrme2178@gmail.com
- Avoid unresolvable errors from multiple providers of libhdf5
* Wed Feb 25 2015 normand@linux.vnet.ibm.com
- new patch meep_change_protos_with_harminv_complex.patch
  required for ppc64 architecture to avoid make check error
  while building meep package.
* Sun Jan 25 2015 dmitry_r@opensuse.org
- Update to version 1.2.1
  * See included NEWS file for details
- Move library to separate package according to SLPP
- Enable post-build testing
* Tue Aug 21 2012 scorot@free.fr
- Buildrequires libguile1 on recent product
* Fri May 11 2012 scorot@free.fr
- remove conditional BuildRequires for blas and lapack since
  recent lapack now build correctly for all suse version
* Sat Apr 14 2012 badshah400@gmail.com
- Update BuildRequires in keeping with lapack package naming
  changes
- Spec file cleanups
- Modify License tag in confomity with spdx.org specifications.
